# coding: utf-8

# flake8: noqa

"""
    Curia Platform API

    These are the docs for the curia platform API. To test, generate an authorization token first.  # noqa: E501

    OpenAPI spec version: 3.8.1-develop.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

# import apis into sdk package
from curia.api.swagger_client.api.cohorts_api import CohortsApi
from curia.api.swagger_client.api.data_queries_api import DataQueriesApi
from curia.api.swagger_client.api.data_stores_api import DataStoresApi
from curia.api.swagger_client.api.data_tables_api import DataTablesApi
from curia.api.swagger_client.api.databases_api import DatabasesApi
from curia.api.swagger_client.api.dataset_columns_api import DatasetColumnsApi
from curia.api.swagger_client.api.datasets_api import DatasetsApi
from curia.api.swagger_client.api.feature_stores_api import FeatureStoresApi
from curia.api.swagger_client.api.features_api import FeaturesApi
from curia.api.swagger_client.api.internal_api import InternalApi
from curia.api.swagger_client.api.model_job_outputs_api import ModelJobOutputsApi
from curia.api.swagger_client.api.model_job_statuses_api import ModelJobStatusesApi
from curia.api.swagger_client.api.model_jobs_api import ModelJobsApi
from curia.api.swagger_client.api.model_populations_api import ModelPopulationsApi
from curia.api.swagger_client.api.models_api import ModelsApi
from curia.api.swagger_client.api.organization_settings_api import OrganizationSettingsApi
from curia.api.swagger_client.api.organizations_api import OrganizationsApi
from curia.api.swagger_client.api.platform_api import PlatformApi
from curia.api.swagger_client.api.population_stores_api import PopulationStoresApi
from curia.api.swagger_client.api.project_members_api import ProjectMembersApi
from curia.api.swagger_client.api.projects_api import ProjectsApi
from curia.api.swagger_client.api.scheduler_api import SchedulerApi
from curia.api.swagger_client.api.tasks_api import TasksApi
from curia.api.swagger_client.api.user_audit_trail_api import UserAuditTrailApi
from curia.api.swagger_client.api.user_favorites_api import UserFavoritesApi
from curia.api.swagger_client.api.user_management_api import UserManagementApi
from curia.api.swagger_client.api.workflows_api import WorkflowsApi
# import ApiClient
from curia.api.swagger_client.api_client import ApiClient
from curia.api.swagger_client.configuration import Configuration
# import models into sdk package
from curia.api.swagger_client.models.all_of_data_table_dataset import AllOfDataTableDataset
from curia.api.swagger_client.models.arithmetic_expression import ArithmeticExpression
from curia.api.swagger_client.models.body import Body
from curia.api.swagger_client.models.body1 import Body1
from curia.api.swagger_client.models.body2 import Body2
from curia.api.swagger_client.models.body3 import Body3
from curia.api.swagger_client.models.body4 import Body4
from curia.api.swagger_client.models.body5 import Body5
from curia.api.swagger_client.models.boolean_expression import BooleanExpression
from curia.api.swagger_client.models.cohort import Cohort
from curia.api.swagger_client.models.cohort_definition import CohortDefinition
from curia.api.swagger_client.models.cohort_filter import CohortFilter
from curia.api.swagger_client.models.cohort_filter_condition import CohortFilterCondition
from curia.api.swagger_client.models.cohort_joined_cohort_response_dto import CohortJoinedCohortResponseDto
from curia.api.swagger_client.models.cohort_joined_model_job_response_dto import CohortJoinedModelJobResponseDto
from curia.api.swagger_client.models.cohort_response_dto import CohortResponseDto
from curia.api.swagger_client.models.cohort_results import CohortResults
from curia.api.swagger_client.models.cohort_window import CohortWindow
from curia.api.swagger_client.models.condition import Condition
from curia.api.swagger_client.models.container_config import ContainerConfig
from curia.api.swagger_client.models.create_cohort_dto import CreateCohortDto
from curia.api.swagger_client.models.create_data_query_dto import CreateDataQueryDto
from curia.api.swagger_client.models.create_data_store_dto import CreateDataStoreDto
from curia.api.swagger_client.models.create_data_table_dto import CreateDataTableDto
from curia.api.swagger_client.models.create_database_dto import CreateDatabaseDto
from curia.api.swagger_client.models.create_dataset_column_dto import CreateDatasetColumnDto
from curia.api.swagger_client.models.create_dataset_dto import CreateDatasetDto
from curia.api.swagger_client.models.create_feature_dto import CreateFeatureDto
from curia.api.swagger_client.models.create_feature_store_dto import CreateFeatureStoreDto
from curia.api.swagger_client.models.create_many_cohort_dto import CreateManyCohortDto
from curia.api.swagger_client.models.create_many_data_query_dto import CreateManyDataQueryDto
from curia.api.swagger_client.models.create_many_data_store_dto import CreateManyDataStoreDto
from curia.api.swagger_client.models.create_many_dataset_column_dto import CreateManyDatasetColumnDto
from curia.api.swagger_client.models.create_many_dataset_dto import CreateManyDatasetDto
from curia.api.swagger_client.models.create_many_feature_dto import CreateManyFeatureDto
from curia.api.swagger_client.models.create_many_feature_store_dto import CreateManyFeatureStoreDto
from curia.api.swagger_client.models.create_many_model_dto import CreateManyModelDto
from curia.api.swagger_client.models.create_many_model_job_dto import CreateManyModelJobDto
from curia.api.swagger_client.models.create_many_model_job_output_dto import CreateManyModelJobOutputDto
from curia.api.swagger_client.models.create_many_model_population_dto import CreateManyModelPopulationDto
from curia.api.swagger_client.models.create_many_organization_dto import CreateManyOrganizationDto
from curia.api.swagger_client.models.create_many_organization_setting_dto import CreateManyOrganizationSettingDto
from curia.api.swagger_client.models.create_many_population_store_dto import CreateManyPopulationStoreDto
from curia.api.swagger_client.models.create_many_project_dto import CreateManyProjectDto
from curia.api.swagger_client.models.create_many_project_member_dto import CreateManyProjectMemberDto
from curia.api.swagger_client.models.create_many_scheduler_dto import CreateManySchedulerDto
from curia.api.swagger_client.models.create_many_task_dto import CreateManyTaskDto
from curia.api.swagger_client.models.create_many_task_execution_dto import CreateManyTaskExecutionDto
from curia.api.swagger_client.models.create_many_task_execution_status_dto import CreateManyTaskExecutionStatusDto
from curia.api.swagger_client.models.create_many_user_favorite_dto import CreateManyUserFavoriteDto
from curia.api.swagger_client.models.create_many_workflow_dto import CreateManyWorkflowDto
from curia.api.swagger_client.models.create_many_workflow_execution_dto import CreateManyWorkflowExecutionDto
from curia.api.swagger_client.models.create_many_workflow_execution_spec_dto import CreateManyWorkflowExecutionSpecDto
from curia.api.swagger_client.models.create_many_workflow_template_dto import CreateManyWorkflowTemplateDto
from curia.api.swagger_client.models.create_model_dto import CreateModelDto
from curia.api.swagger_client.models.create_model_job_dto import CreateModelJobDto
from curia.api.swagger_client.models.create_model_job_output_dto import CreateModelJobOutputDto
from curia.api.swagger_client.models.create_model_job_status_dto import CreateModelJobStatusDto
from curia.api.swagger_client.models.create_model_population_dto import CreateModelPopulationDto
from curia.api.swagger_client.models.create_organization_dto import CreateOrganizationDto
from curia.api.swagger_client.models.create_organization_setting_dto import CreateOrganizationSettingDto
from curia.api.swagger_client.models.create_population_store_dto import CreatePopulationStoreDto
from curia.api.swagger_client.models.create_project_dto import CreateProjectDto
from curia.api.swagger_client.models.create_project_member_dto import CreateProjectMemberDto
from curia.api.swagger_client.models.create_scheduler_dto import CreateSchedulerDto
from curia.api.swagger_client.models.create_task_dto import CreateTaskDto
from curia.api.swagger_client.models.create_task_execution_dto import CreateTaskExecutionDto
from curia.api.swagger_client.models.create_task_execution_status_dto import CreateTaskExecutionStatusDto
from curia.api.swagger_client.models.create_user_audit_trail_dto import CreateUserAuditTrailDto
from curia.api.swagger_client.models.create_user_favorite_dto import CreateUserFavoriteDto
from curia.api.swagger_client.models.create_workflow_dto import CreateWorkflowDto
from curia.api.swagger_client.models.create_workflow_execution_dto import CreateWorkflowExecutionDto
from curia.api.swagger_client.models.create_workflow_execution_spec_dto import CreateWorkflowExecutionSpecDto
from curia.api.swagger_client.models.create_workflow_execution_status_dto import CreateWorkflowExecutionStatusDto
from curia.api.swagger_client.models.create_workflow_template_dto import CreateWorkflowTemplateDto
from curia.api.swagger_client.models.data_query import DataQuery
from curia.api.swagger_client.models.data_query_joined_dataset_response_dto import DataQueryJoinedDatasetResponseDto
from curia.api.swagger_client.models.data_query_response_dto import DataQueryResponseDto
from curia.api.swagger_client.models.data_store import DataStore
from curia.api.swagger_client.models.data_store_response_dto import DataStoreResponseDto
from curia.api.swagger_client.models.data_table import DataTable
from curia.api.swagger_client.models.data_table_joined_database_response_dto import DataTableJoinedDatabaseResponseDto
from curia.api.swagger_client.models.data_table_joined_dataset_response_dto import DataTableJoinedDatasetResponseDto
from curia.api.swagger_client.models.data_table_response_dto import DataTableResponseDto
from curia.api.swagger_client.models.database import Database
from curia.api.swagger_client.models.database_joined_data_table_response_dto import DatabaseJoinedDataTableResponseDto
from curia.api.swagger_client.models.database_response_dto import DatabaseResponseDto
from curia.api.swagger_client.models.dataset import Dataset
from curia.api.swagger_client.models.dataset_column import DatasetColumn
from curia.api.swagger_client.models.dataset_column_joined_dataset_response_dto import DatasetColumnJoinedDatasetResponseDto
from curia.api.swagger_client.models.dataset_column_response_dto import DatasetColumnResponseDto
from curia.api.swagger_client.models.dataset_joined_data_query_response_dto import DatasetJoinedDataQueryResponseDto
from curia.api.swagger_client.models.dataset_joined_dataset_column_response_dto import DatasetJoinedDatasetColumnResponseDto
from curia.api.swagger_client.models.dataset_response_dto import DatasetResponseDto
from curia.api.swagger_client.models.datasetsuploadlargecomplete_parts import DatasetsuploadlargecompleteParts
from curia.api.swagger_client.models.feature import Feature
from curia.api.swagger_client.models.feature_category import FeatureCategory
from curia.api.swagger_client.models.feature_joined_feature_sub_category_joined_feature_category_response_dto import FeatureJoinedFeatureSubCategoryJoinedFeatureCategoryResponseDto
from curia.api.swagger_client.models.feature_joined_feature_sub_category_response_dto import FeatureJoinedFeatureSubCategoryResponseDto
from curia.api.swagger_client.models.feature_joined_model_population_response_dto import FeatureJoinedModelPopulationResponseDto
from curia.api.swagger_client.models.feature_joined_organization_feature_exclusion_response_dto import FeatureJoinedOrganizationFeatureExclusionResponseDto
from curia.api.swagger_client.models.feature_response_dto import FeatureResponseDto
from curia.api.swagger_client.models.feature_store import FeatureStore
from curia.api.swagger_client.models.feature_store_response_dto import FeatureStoreResponseDto
from curia.api.swagger_client.models.feature_sub_category import FeatureSubCategory
from curia.api.swagger_client.models.geographic_counts import GeographicCounts
from curia.api.swagger_client.models.geographic_queries import GeographicQueries
from curia.api.swagger_client.models.get_many_cohort_response_dto import GetManyCohortResponseDto
from curia.api.swagger_client.models.get_many_data_query_response_dto import GetManyDataQueryResponseDto
from curia.api.swagger_client.models.get_many_data_store_response_dto import GetManyDataStoreResponseDto
from curia.api.swagger_client.models.get_many_data_table_response_dto import GetManyDataTableResponseDto
from curia.api.swagger_client.models.get_many_database_response_dto import GetManyDatabaseResponseDto
from curia.api.swagger_client.models.get_many_dataset_column_response_dto import GetManyDatasetColumnResponseDto
from curia.api.swagger_client.models.get_many_dataset_response_dto import GetManyDatasetResponseDto
from curia.api.swagger_client.models.get_many_feature_response_dto import GetManyFeatureResponseDto
from curia.api.swagger_client.models.get_many_feature_store_response_dto import GetManyFeatureStoreResponseDto
from curia.api.swagger_client.models.get_many_model_job_output_response_dto import GetManyModelJobOutputResponseDto
from curia.api.swagger_client.models.get_many_model_job_response_dto import GetManyModelJobResponseDto
from curia.api.swagger_client.models.get_many_model_job_status_response_dto import GetManyModelJobStatusResponseDto
from curia.api.swagger_client.models.get_many_model_population_response_dto import GetManyModelPopulationResponseDto
from curia.api.swagger_client.models.get_many_model_response_dto import GetManyModelResponseDto
from curia.api.swagger_client.models.get_many_organization_response_dto import GetManyOrganizationResponseDto
from curia.api.swagger_client.models.get_many_organization_setting_response_dto import GetManyOrganizationSettingResponseDto
from curia.api.swagger_client.models.get_many_population_store_response_dto import GetManyPopulationStoreResponseDto
from curia.api.swagger_client.models.get_many_project_member_response_dto import GetManyProjectMemberResponseDto
from curia.api.swagger_client.models.get_many_project_response_dto import GetManyProjectResponseDto
from curia.api.swagger_client.models.get_many_scheduler_response_dto import GetManySchedulerResponseDto
from curia.api.swagger_client.models.get_many_task_execution_response_dto import GetManyTaskExecutionResponseDto
from curia.api.swagger_client.models.get_many_task_execution_status_response_dto import GetManyTaskExecutionStatusResponseDto
from curia.api.swagger_client.models.get_many_task_response_dto import GetManyTaskResponseDto
from curia.api.swagger_client.models.get_many_user_audit_trail_response_dto import GetManyUserAuditTrailResponseDto
from curia.api.swagger_client.models.get_many_user_favorite_response_dto import GetManyUserFavoriteResponseDto
from curia.api.swagger_client.models.get_many_workflow_execution_response_dto import GetManyWorkflowExecutionResponseDto
from curia.api.swagger_client.models.get_many_workflow_execution_spec_response_dto import GetManyWorkflowExecutionSpecResponseDto
from curia.api.swagger_client.models.get_many_workflow_execution_status_response_dto import GetManyWorkflowExecutionStatusResponseDto
from curia.api.swagger_client.models.get_many_workflow_response_dto import GetManyWorkflowResponseDto
from curia.api.swagger_client.models.get_many_workflow_template_response_dto import GetManyWorkflowTemplateResponseDto
from curia.api.swagger_client.models.intervention_definition import InterventionDefinition
from curia.api.swagger_client.models.json import Json
from curia.api.swagger_client.models.model import Model
from curia.api.swagger_client.models.model_job import ModelJob
from curia.api.swagger_client.models.model_job_config import ModelJobConfig
from curia.api.swagger_client.models.model_job_event import ModelJobEvent
from curia.api.swagger_client.models.model_job_joined_cohort_response_dto import ModelJobJoinedCohortResponseDto
from curia.api.swagger_client.models.model_job_joined_data_query_response_dto import ModelJobJoinedDataQueryResponseDto
from curia.api.swagger_client.models.model_job_joined_dataset_response_dto import ModelJobJoinedDatasetResponseDto
from curia.api.swagger_client.models.model_job_joined_feature_sub_category_response_dto import ModelJobJoinedFeatureSubCategoryResponseDto
from curia.api.swagger_client.models.model_job_joined_model_job_output_response_dto import ModelJobJoinedModelJobOutputResponseDto
from curia.api.swagger_client.models.model_job_joined_model_job_status_response_dto import ModelJobJoinedModelJobStatusResponseDto
from curia.api.swagger_client.models.model_job_joined_model_population_joined_cohort_definition_joined_period_definition_response_dto import ModelJobJoinedModelPopulationJoinedCohortDefinitionJoinedPeriodDefinitionResponseDto
from curia.api.swagger_client.models.model_job_joined_model_population_joined_cohort_definition_response_dto import ModelJobJoinedModelPopulationJoinedCohortDefinitionResponseDto
from curia.api.swagger_client.models.model_job_joined_model_population_joined_data_query_joined_dataset_response_dto import ModelJobJoinedModelPopulationJoinedDataQueryJoinedDatasetResponseDto
from curia.api.swagger_client.models.model_job_joined_model_population_joined_data_query_response_dto import ModelJobJoinedModelPopulationJoinedDataQueryResponseDto
from curia.api.swagger_client.models.model_job_joined_model_population_joined_intervention_definition_response_dto import ModelJobJoinedModelPopulationJoinedInterventionDefinitionResponseDto
from curia.api.swagger_client.models.model_job_joined_model_population_joined_outcome_definition_response_dto import ModelJobJoinedModelPopulationJoinedOutcomeDefinitionResponseDto
from curia.api.swagger_client.models.model_job_joined_model_population_response_dto import ModelJobJoinedModelPopulationResponseDto
from curia.api.swagger_client.models.model_job_joined_model_response_dto import ModelJobJoinedModelResponseDto
from curia.api.swagger_client.models.model_job_joined_project_response_dto import ModelJobJoinedProjectResponseDto
from curia.api.swagger_client.models.model_job_output import ModelJobOutput
from curia.api.swagger_client.models.model_job_output_joined_dataset_response_dto import ModelJobOutputJoinedDatasetResponseDto
from curia.api.swagger_client.models.model_job_output_joined_model_job_joined_project_response_dto import ModelJobOutputJoinedModelJobJoinedProjectResponseDto
from curia.api.swagger_client.models.model_job_output_joined_model_job_response_dto import ModelJobOutputJoinedModelJobResponseDto
from curia.api.swagger_client.models.model_job_output_response_dto import ModelJobOutputResponseDto
from curia.api.swagger_client.models.model_job_response_dto import ModelJobResponseDto
from curia.api.swagger_client.models.model_job_status import ModelJobStatus
from curia.api.swagger_client.models.model_job_status_joined_model_job_joined_project_response_dto import ModelJobStatusJoinedModelJobJoinedProjectResponseDto
from curia.api.swagger_client.models.model_job_status_joined_model_job_response_dto import ModelJobStatusJoinedModelJobResponseDto
from curia.api.swagger_client.models.model_job_status_response_dto import ModelJobStatusResponseDto
from curia.api.swagger_client.models.model_joined_cohort_joined_model_job_response_dto import ModelJoinedCohortJoinedModelJobResponseDto
from curia.api.swagger_client.models.model_joined_cohort_response_dto import ModelJoinedCohortResponseDto
from curia.api.swagger_client.models.model_joined_model_job_joined_cohort_response_dto import ModelJoinedModelJobJoinedCohortResponseDto
from curia.api.swagger_client.models.model_joined_model_job_joined_dataset_response_dto import ModelJoinedModelJobJoinedDatasetResponseDto
from curia.api.swagger_client.models.model_joined_model_job_joined_feature_sub_category_response_dto import ModelJoinedModelJobJoinedFeatureSubCategoryResponseDto
from curia.api.swagger_client.models.model_joined_model_job_response_dto import ModelJoinedModelJobResponseDto
from curia.api.swagger_client.models.model_joined_model_output_details_response_dto import ModelJoinedModelOutputDetailsResponseDto
from curia.api.swagger_client.models.model_joined_project_response_dto import ModelJoinedProjectResponseDto
from curia.api.swagger_client.models.model_joined_user_favorite_response_dto import ModelJoinedUserFavoriteResponseDto
from curia.api.swagger_client.models.model_output_details import ModelOutputDetails
from curia.api.swagger_client.models.model_population import ModelPopulation
from curia.api.swagger_client.models.model_population_joined_cohort_definition_joined_period_definition_response_dto import ModelPopulationJoinedCohortDefinitionJoinedPeriodDefinitionResponseDto
from curia.api.swagger_client.models.model_population_joined_cohort_definition_response_dto import ModelPopulationJoinedCohortDefinitionResponseDto
from curia.api.swagger_client.models.model_population_joined_cohort_results_response_dto import ModelPopulationJoinedCohortResultsResponseDto
from curia.api.swagger_client.models.model_population_joined_data_query_joined_dataset_response_dto import ModelPopulationJoinedDataQueryJoinedDatasetResponseDto
from curia.api.swagger_client.models.model_population_joined_data_query_response_dto import ModelPopulationJoinedDataQueryResponseDto
from curia.api.swagger_client.models.model_population_joined_feature_response_dto import ModelPopulationJoinedFeatureResponseDto
from curia.api.swagger_client.models.model_population_joined_intervention_definition_response_dto import ModelPopulationJoinedInterventionDefinitionResponseDto
from curia.api.swagger_client.models.model_population_joined_model_job_joined_model_response_dto import ModelPopulationJoinedModelJobJoinedModelResponseDto
from curia.api.swagger_client.models.model_population_joined_model_job_response_dto import ModelPopulationJoinedModelJobResponseDto
from curia.api.swagger_client.models.model_population_joined_outcome_definition_response_dto import ModelPopulationJoinedOutcomeDefinitionResponseDto
from curia.api.swagger_client.models.model_population_response_dto import ModelPopulationResponseDto
from curia.api.swagger_client.models.model_response_dto import ModelResponseDto
from curia.api.swagger_client.models.object import Object
from curia.api.swagger_client.models.organization import Organization
from curia.api.swagger_client.models.organization_feature_category_exclusion import OrganizationFeatureCategoryExclusion
from curia.api.swagger_client.models.organization_feature_exclusion import OrganizationFeatureExclusion
from curia.api.swagger_client.models.organization_response_dto import OrganizationResponseDto
from curia.api.swagger_client.models.organization_setting import OrganizationSetting
from curia.api.swagger_client.models.organization_setting_response_dto import OrganizationSettingResponseDto
from curia.api.swagger_client.models.outcome_definition import OutcomeDefinition
from curia.api.swagger_client.models.period_definition import PeriodDefinition
from curia.api.swagger_client.models.person_set import PersonSet
from curia.api.swagger_client.models.pipeline_config import PipelineConfig
from curia.api.swagger_client.models.population import Population
from curia.api.swagger_client.models.population_store import PopulationStore
from curia.api.swagger_client.models.population_store_response_dto import PopulationStoreResponseDto
from curia.api.swagger_client.models.project import Project
from curia.api.swagger_client.models.project_joined_model_joined_cohort_response_dto import ProjectJoinedModelJoinedCohortResponseDto
from curia.api.swagger_client.models.project_joined_model_response_dto import ProjectJoinedModelResponseDto
from curia.api.swagger_client.models.project_joined_project_response_dto import ProjectJoinedProjectResponseDto
from curia.api.swagger_client.models.project_joined_user_favorite_response_dto import ProjectJoinedUserFavoriteResponseDto
from curia.api.swagger_client.models.project_member import ProjectMember
from curia.api.swagger_client.models.project_member_joined_project_response_dto import ProjectMemberJoinedProjectResponseDto
from curia.api.swagger_client.models.project_member_response_dto import ProjectMemberResponseDto
from curia.api.swagger_client.models.project_response_dto import ProjectResponseDto
from curia.api.swagger_client.models.scheduler import Scheduler
from curia.api.swagger_client.models.scheduler_joined_workflow_response_dto import SchedulerJoinedWorkflowResponseDto
from curia.api.swagger_client.models.scheduler_response_dto import SchedulerResponseDto
from curia.api.swagger_client.models.select_expression import SelectExpression
from curia.api.swagger_client.models.state_data import StateData
from curia.api.swagger_client.models.task import Task
from curia.api.swagger_client.models.task_execution import TaskExecution
from curia.api.swagger_client.models.task_execution_joined_task_response_dto import TaskExecutionJoinedTaskResponseDto
from curia.api.swagger_client.models.task_execution_joined_workflow_execution_response_dto import TaskExecutionJoinedWorkflowExecutionResponseDto
from curia.api.swagger_client.models.task_execution_response_dto import TaskExecutionResponseDto
from curia.api.swagger_client.models.task_execution_status import TaskExecutionStatus
from curia.api.swagger_client.models.task_execution_status_joined_task_execution_joined_workflow_execution_response_dto import TaskExecutionStatusJoinedTaskExecutionJoinedWorkflowExecutionResponseDto
from curia.api.swagger_client.models.task_execution_status_joined_task_execution_response_dto import TaskExecutionStatusJoinedTaskExecutionResponseDto
from curia.api.swagger_client.models.task_execution_status_response_dto import TaskExecutionStatusResponseDto
from curia.api.swagger_client.models.task_inputs import TaskInputs
from curia.api.swagger_client.models.task_outputs import TaskOutputs
from curia.api.swagger_client.models.task_response_dto import TaskResponseDto
from curia.api.swagger_client.models.update_cohort_dto import UpdateCohortDto
from curia.api.swagger_client.models.update_data_query_dto import UpdateDataQueryDto
from curia.api.swagger_client.models.update_data_store_dto import UpdateDataStoreDto
from curia.api.swagger_client.models.update_data_table_dto import UpdateDataTableDto
from curia.api.swagger_client.models.update_database_dto import UpdateDatabaseDto
from curia.api.swagger_client.models.update_dataset_column_dto import UpdateDatasetColumnDto
from curia.api.swagger_client.models.update_dataset_dto import UpdateDatasetDto
from curia.api.swagger_client.models.update_feature_dto import UpdateFeatureDto
from curia.api.swagger_client.models.update_feature_store_dto import UpdateFeatureStoreDto
from curia.api.swagger_client.models.update_model_dto import UpdateModelDto
from curia.api.swagger_client.models.update_model_job_dto import UpdateModelJobDto
from curia.api.swagger_client.models.update_model_job_output_dto import UpdateModelJobOutputDto
from curia.api.swagger_client.models.update_model_job_status_dto import UpdateModelJobStatusDto
from curia.api.swagger_client.models.update_model_population_dto import UpdateModelPopulationDto
from curia.api.swagger_client.models.update_organization_dto import UpdateOrganizationDto
from curia.api.swagger_client.models.update_organization_setting_dto import UpdateOrganizationSettingDto
from curia.api.swagger_client.models.update_population_store_dto import UpdatePopulationStoreDto
from curia.api.swagger_client.models.update_project_dto import UpdateProjectDto
from curia.api.swagger_client.models.update_project_member_dto import UpdateProjectMemberDto
from curia.api.swagger_client.models.update_scheduler_dto import UpdateSchedulerDto
from curia.api.swagger_client.models.update_task_dto import UpdateTaskDto
from curia.api.swagger_client.models.update_task_execution_dto import UpdateTaskExecutionDto
from curia.api.swagger_client.models.update_task_execution_status_dto import UpdateTaskExecutionStatusDto
from curia.api.swagger_client.models.update_user_audit_trail_dto import UpdateUserAuditTrailDto
from curia.api.swagger_client.models.update_user_dto import UpdateUserDto
from curia.api.swagger_client.models.update_user_favorite_dto import UpdateUserFavoriteDto
from curia.api.swagger_client.models.update_workflow_dto import UpdateWorkflowDto
from curia.api.swagger_client.models.update_workflow_execution_dto import UpdateWorkflowExecutionDto
from curia.api.swagger_client.models.update_workflow_execution_spec_dto import UpdateWorkflowExecutionSpecDto
from curia.api.swagger_client.models.update_workflow_execution_status_dto import UpdateWorkflowExecutionStatusDto
from curia.api.swagger_client.models.update_workflow_template_dto import UpdateWorkflowTemplateDto
from curia.api.swagger_client.models.user_audit_trail_response_dto import UserAuditTrailResponseDto
from curia.api.swagger_client.models.user_favorite import UserFavorite
from curia.api.swagger_client.models.user_favorite_joined_model_joined_project_response_dto import UserFavoriteJoinedModelJoinedProjectResponseDto
from curia.api.swagger_client.models.user_favorite_joined_model_response_dto import UserFavoriteJoinedModelResponseDto
from curia.api.swagger_client.models.user_favorite_response_dto import UserFavoriteResponseDto
from curia.api.swagger_client.models.workflow import Workflow
from curia.api.swagger_client.models.workflow_execution import WorkflowExecution
from curia.api.swagger_client.models.workflow_execution_response_dto import WorkflowExecutionResponseDto
from curia.api.swagger_client.models.workflow_execution_spec import WorkflowExecutionSpec
from curia.api.swagger_client.models.workflow_execution_spec_joined_workflow_execution_response_dto import WorkflowExecutionSpecJoinedWorkflowExecutionResponseDto
from curia.api.swagger_client.models.workflow_execution_spec_response_dto import WorkflowExecutionSpecResponseDto
from curia.api.swagger_client.models.workflow_execution_status import WorkflowExecutionStatus
from curia.api.swagger_client.models.workflow_execution_status_joined_workflow_execution_response_dto import WorkflowExecutionStatusJoinedWorkflowExecutionResponseDto
from curia.api.swagger_client.models.workflow_execution_status_response_dto import WorkflowExecutionStatusResponseDto
from curia.api.swagger_client.models.workflow_joined_scheduler_response_dto import WorkflowJoinedSchedulerResponseDto
from curia.api.swagger_client.models.workflow_joined_workflow_execution_response_dto import WorkflowJoinedWorkflowExecutionResponseDto
from curia.api.swagger_client.models.workflow_joined_workflow_template_response_dto import WorkflowJoinedWorkflowTemplateResponseDto
from curia.api.swagger_client.models.workflow_response_dto import WorkflowResponseDto
from curia.api.swagger_client.models.workflow_template import WorkflowTemplate
from curia.api.swagger_client.models.workflow_template_definition import WorkflowTemplateDefinition
from curia.api.swagger_client.models.workflow_template_parameters import WorkflowTemplateParameters
from curia.api.swagger_client.models.workflow_template_response_dto import WorkflowTemplateResponseDto
from curia.api.swagger_client.models.zip_data import ZipData
